@@ -1,7 +1,6 @@
 # flake8: noqa
 """Module implementing the clients for services."""
-from npc_engine.service_clients.service_client import ServiceClient
-from npc_engine.service_clients.chatbot_client import ChatbotClient
+from npc_engine.service_clients.text_generation_client import TextGenerationClient
 from npc_engine.service_clients.control_client import ControlClient
 from npc_engine.service_clients.sequence_classifier_client import (
     SequenceClassifierClient,
